#include <qfiledlg.h>
#include <qfile.h>
#include <kapp.h>
#include <kmenubar.h>
#include <qstring.h>
#include <qmsgbox.h>
#include "edit.h"

// Define command codes
#define ID_OPEN 100
#define ID_NEW 101
#define ID_SAVE 102
#define ID_SAVEAS 103
#define ID_EXIT 107
#define ID_ABOUT 108

Edit::Edit()
  : filename_()
{
  initMenuBar();
  view= new QMultiLineEdit(this, "Main View");
  setView(view);
  show();
}

Edit::~Edit()
{

}

void Edit::commandCallback(int id_)
{
  QString name;

  switch(id_) {
  case ID_NEW:
    view->clear();
    filename_= "";
    break;
  case ID_OPEN:
    name= QFileDialog::getOpenFileName();
    if (!name.isEmpty())
      load(name);
    break;
  case ID_SAVE:
    if (!filename_.isEmpty())
      saveAs(filename_);
    else {
      name= QFileDialog::getSaveFileName();
      if (!name.isEmpty())
        saveAs(name);
    }
    break;
  case ID_SAVEAS:
    name= QFileDialog::getSaveFileName();
    if (!name.isEmpty())
      saveAs(name);
    break;
  case ID_ABOUT:
    QMessageBox::about(this, "About Edit",
		       "This is a simple text editor example program.");
    break;
  case ID_EXIT:
    exit(0);
    break;
  }
}

void Edit::saveAs(const char *filename) {
    QFile f( filename );
    if ( !f.open( IO_WriteOnly ) )
	return;

    QTextStream t(&f);

    t << view->text();

    f.close();

    filename_= filename;
}

void Edit::load(const char *filename) {
    QFile f( filename );
    if ( !f.open( IO_ReadOnly ) )
	return;

    view->setAutoUpdate( FALSE );
    view->clear();

    QTextStream t(&f);
    while ( !t.eof() ) {
	QString s = t.readLine();
	view->append( s );
    }
    f.close();

    view->setAutoUpdate( TRUE );
    view->repaint();
    filename_= filename;
}

void Edit::initMenuBar()
{
  QPopupMenu *file = new QPopupMenu;

  file->insertItem(klocale->translate("Open..."), ID_OPEN );
  file->insertItem(klocale->translate("New..."), ID_NEW );
  file->insertItem(klocale->translate("Save"), ID_SAVE);
  file->insertItem(klocale->translate("Save As..."), ID_SAVEAS);
  file->insertSeparator();
  file->insertItem(klocale->translate("Exit"), ID_EXIT);

  QPopupMenu *help = new QPopupMenu;
  help->insertItem( klocale->translate("About..."), ID_ABOUT);

  menu = new KMenuBar( this );
  CHECK_PTR( menu );
  menu->insertItem( klocale->translate("&File"), file );
  menu->insertSeparator();
  menu->insertItem( klocale->translate("&Help"), help );
  menu->show();
  setMenu(menu);

  // Connect things together
  connect (file, SIGNAL (activated (int)), SLOT (commandCallback (int)));
  connect (help, SIGNAL (activated (int)), SLOT (commandCallback (int)));
}

#include "edit.moc"
